@@ -10,10 +10,21 @@ import argparse
 import inspect
 import numbers
 import shutil
-from collections import deque
-from typing import Dict, List, Optional, Union
+from collections import (
+    deque,
+)
+from typing import (
+    Dict,
+    List,
+    Optional,
+    Union,
+)
 
-from . import ansi, cmd2, constants
+from . import (
+    ansi,
+    cmd2,
+    constants,
+)
 from .argparse_custom import (
     ATTR_CHOICES_CALLABLE,
     ATTR_DESCRIPTIVE_COMPLETION_HEADER,
@@ -23,9 +34,17 @@ from .argparse_custom import (
     CompletionItem,
     generate_range_error,
 )
-from .command_definition import CommandSet
-from .table_creator import Column, SimpleTable
-from .utils import CompletionError, basic_complete
+from .command_definition import (
+    CommandSet,
+)
+from .table_creator import (
+    Column,
+    SimpleTable,
+)
+from .utils import (
+    CompletionError,
+    basic_complete,
+)
 
 # If no descriptive header is supplied, then this will be used instead
 DEFAULT_DESCRIPTIVE_HEADER = 'Description'
@@ -415,7 +434,9 @@ class ArgparseCompleter:
 
             # If we have results, then return them
             if completion_results:
-                self._cmd2_app.completion_hint = _build_hint(self._parser, flag_arg_state.action)
+                # Don't overwrite an existing hint
+                if not self._cmd2_app.completion_hint:
+                    self._cmd2_app.completion_hint = _build_hint(self._parser, flag_arg_state.action)
                 return completion_results
 
             # Otherwise, print a hint if the flag isn't finished or text isn't possibly the start of a flag
@@ -437,7 +458,9 @@ class ArgparseCompleter:
 
             # If we have results, then return them
             if completion_results:
-                self._cmd2_app.completion_hint = _build_hint(self._parser, pos_arg_state.action)
+                # Don't overwrite an existing hint
+                if not self._cmd2_app.completion_hint:
+                    self._cmd2_app.completion_hint = _build_hint(self._parser, pos_arg_state.action)
                 return completion_results
 
             # Otherwise, print a hint if text isn't possibly the start of a flag
