@@ -25,6 +25,10 @@ class Cmd2ArgparseError(SkipPostcommandHooks):
 
 
 class CommandSetRegistrationError(Exception):
+    """
+    Exception that can be thrown when an error occurs while a CommandSet is being added or removed
+    from a cmd2 application.
+    """
     pass
 
 ############################################################################################################
