@@ -11,9 +11,14 @@ class is used in cmd2.py::run_transcript_tests()
 """
 import re
 import unittest
-from typing import Tuple
+from typing import (
+    Tuple,
+)
 
-from . import ansi, utils
+from . import (
+    ansi,
+    utils,
+)
 
 
 class Cmd2TestCase(unittest.TestCase):
