@@ -6,17 +6,32 @@ import collections.abc as collections_abc
 import functools
 import glob
 import inspect
+import itertools
 import os
 import re
 import subprocess
 import sys
 import threading
-
 import unicodedata
-from enum import Enum
-from typing import Any, Callable, Dict, IO, Iterable, List, Optional, TextIO, Type, Union
+from enum import (
+    Enum,
+)
+from typing import (
+    IO,
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    TextIO,
+    Type,
+    Union,
+)
 
-from . import constants
+from . import (
+    constants,
+)
 
 
 def is_quoted(arg: str) -> bool:
@@ -188,23 +203,6 @@ def namedtuple_with_defaults(typename: str, field_names: Union[str, List[str]],
     return T
 
 
-def which(exe_name: str) -> Optional[str]:
-    """Find the full path of a given executable on a Linux or Mac machine
-
-    :param exe_name: name of the executable to check, ie 'vi' or 'ls'
-    :return: a full path or None if exe not found
-    """
-    if sys.platform.startswith('win'):
-        return None
-
-    try:
-        exe_path = subprocess.check_output(['which', exe_name], stderr=subprocess.STDOUT).strip()
-        exe_path = exe_path.decode()
-    except subprocess.CalledProcessError:
-        exe_path = None
-    return exe_path
-
-
 def is_text_file(file_path: str) -> bool:
     """Returns if a file contains only ASCII or UTF-8 encoded text.
 
@@ -318,17 +316,29 @@ def natural_sort(list_to_sort: Iterable[str]) -> List[str]:
     return sorted(list_to_sort, key=natural_keys)
 
 
-def unquote_specific_tokens(args: List[str], tokens_to_unquote: List[str]) -> None:
+def quote_specific_tokens(tokens: List[str], tokens_to_quote: List[str]) -> None:
     """
-    Unquote a specific tokens in a list of command-line arguments
-    This is used when certain tokens have to be passed to another command
-    :param args: the command line args
-    :param tokens_to_unquote: the tokens, which if present in args, to unquote
+    Quote specific tokens in a list
+
+    :param tokens: token list being edited
+    :param tokens_to_quote: the tokens, which if present in tokens, to quote
     """
-    for i, arg in enumerate(args):
-        unquoted_arg = strip_quotes(arg)
-        if unquoted_arg in tokens_to_unquote:
-            args[i] = unquoted_arg
+    for i, token in enumerate(tokens):
+        if token in tokens_to_quote:
+            tokens[i] = quote_string(token)
+
+
+def unquote_specific_tokens(tokens: List[str], tokens_to_unquote: List[str]) -> None:
+    """
+    Unquote specific tokens in a list
+
+    :param tokens: token list being edited
+    :param tokens_to_unquote: the tokens, which if present in tokens, to unquote
+    """
+    for i, token in enumerate(tokens):
+        unquoted_token = strip_quotes(token)
+        if unquoted_token in tokens_to_unquote:
+            tokens[i] = unquoted_token
 
 
 def expand_user(token: str) -> str:
@@ -361,17 +371,30 @@ def expand_user_in_tokens(tokens: List[str]) -> None:
         tokens[index] = expand_user(tokens[index])
 
 
-def find_editor() -> str:
-    """Find a reasonable editor to use by default for the system that the cmd2 application is running on."""
+def find_editor() -> Optional[str]:
+    """
+    Used to set cmd2.Cmd.DEFAULT_EDITOR. If EDITOR env variable is set, that will be used.
+    Otherwise the function will look for a known editor in directories specified by PATH env variable.
+    :return: Default editor or None
+    """
     editor = os.environ.get('EDITOR')
     if not editor:
         if sys.platform[:3] == 'win':
-            editor = 'notepad'
+            editors = ['code.cmd', 'notepad++.exe', 'notepad.exe']
         else:
-            # Favor command-line editors first so we don't leave the terminal to edit
-            for editor in ['vim', 'vi', 'emacs', 'nano', 'pico', 'gedit', 'kate', 'subl', 'geany', 'atom']:
-                if which(editor):
-                    break
+            editors = ['vim', 'vi', 'emacs', 'nano', 'pico', 'joe', 'code', 'subl', 'atom', 'gedit', 'geany', 'kate']
+
+        paths = [p for p in os.getenv('PATH').split(os.path.pathsep) if not os.path.islink(p)]
+        for editor, path in itertools.product(editors, paths):
+            editor_path = os.path.join(path, editor)
+            if os.path.isfile(editor_path) and os.access(editor_path, os.X_OK):
+                if sys.platform[:3] == 'win':
+                    # Remove extension from Windows file names
+                    editor = os.path.splitext(editor)[0]
+                break
+        else:
+            editor = None
+
     return editor
 
 
